import * as React from 'react';
import { Platform, StatusBarStyle, View, ViewStyle } from 'react-native';
import { FocusAwareStatusBar, SafeAreaView } from '../components/ui';
import { getColor } from './style-utils';

interface TopNavigationProps {
  children: React.ReactNode;
  backgroundColor?: string;
  className?: any;
  barStyle?: null | StatusBarStyle | undefined;
}

const TopNavigation = React.forwardRef<View, TopNavigationProps>(
  (
    {
      children,
      backgroundColor = '#000000',
      className,
      barStyle = 'dark-content',
    },
    ref,
  ) => {
    const isDarkBackground = backgroundColor === '#000000';
    const Container = Platform.OS === 'ios' ? SafeAreaView : View;

    return (
      <View
        ref={ref}
        className={`flex-1 ${className}`}
        style={[{ backgroundColor: getColor(backgroundColor) }]}
      >
        <FocusAwareStatusBar
          barStyle={barStyle}
          backgroundColor={backgroundColor}
          translucent={false}
        />
        <Container
          style={{ flex: 1, backgroundColor: getColor(backgroundColor) }}
          {...(Platform.OS === 'ios' ? { edges: ['top'] } : {})}
        >
          {children}
        </Container>
      </View>
    );
  },
);

export default TopNavigation;
